=============
marv-robotics
=============

*This package is part of MARV Robotics.*

MARV Robotics is a powerful and extensible data management platform,
featuring a rich dynamic web interface, driven by your algorithms,
configurable to the core, and integrating well with your tools to
supercharge your workflows.

For more information please see:

- MARV Robotics `website <https://ternaris.com/marv-robotics/>`_
- MARV Robotics `documentation <https://ternaris.com/marv-robotics/docs/>`_
